class InvalidToken(Exception):
    """
    Invalid token Exception
    """

class AttachmentNotReady(Exception):
    """
    Attachment not ready Exception
    """

class ChatNotFound(Exception):
    """
    Chat not found Exception
    """